#!/bin/bash
# packager          : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# homepage			: http://gajim.org
# source location	: http://www.gajim.org/downloads/0.13.4/gajim-0.13.4.tar.bz2
# dependency        : sqlite

set -x -e -u

softname='gajim'
softversion='0.13.4'
packageversion='64.1'

arch='i486'
cpu='i686'

prefix=/usr

# log
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.bz2"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://www.gajim.org/downloads/0.13/$softname-$softversion.tar.bz2

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/share/icons/hicolor/64x64/apps/
mkdir -p $dest/usr/src/$softname-$softversion

# put slack-desc in place
cat <<EOF > $dest/install/slack-desc
     |-----handy-ruler------------------------------------------------------|
gajim: GTK2+ Jabber/XMPP client
gajim:
gajim: The goal of Gajim is to provide a full featured and easy to use
gajim: Jabber client. 
gajim: 
gajim:
gajim:
gajim:
gajim: 
gajim:
gajim:
EOF

#
# Verifie si package est present
#
if [ -f $softname-$softversion.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

#
# extraire les sources
#
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
#
cd $buildir
tar xvf $srcpkg
cd $src

# building
    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

#patch -p1 < ../gajim-0.13.1-pygtk.patch

    ./configure \
      --prefix=$prefix \
      --mandir=$prefix/man \
      --docdir=$prefix/doc/$softname-$softversion \
      --disable-gtkspell \
      --program-prefix="" \
      --program-suffix="" \
            
    make
    make install DESTDIR=$dest

# Strip
( cd $dest
  find . | xargs file | grep -e "executable" -e "shared object" | grep ELF | cut -s -f 1 -d : | xargs -r strip --strip-unneeded 2> /dev/null
)

# Compress Man Pages
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# freedesktop compliant
cp $dest/usr/share/pixmaps/gajim.png $dest/usr/share/icons/hicolor/64x64/apps/gajim.png

# ZenBuild
cp $buildir/build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

#
# produire le fichier .dep
#
cd $buildir
echo -e "atk,cairo,expat,fontconfig,freetype,glib2,gtk+2,\
libX11,libXau,libXcomposite,libXcursor,libXdamage,libXdmcp,libXext,\
libXfixes,libXi,libXinerama,libXrandr,libXrender,libpng,libxcb,pango,\
pixman,xcb-util,zlib" > $package.dep

#
# supprimer source
#
rm -rf $src
rm -rf $dest

#
# produire le fichier src
#
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/xap/gajim/source/build-gajim.sh > $package.src
echo $source >>$package.src

#
# log
#
) 2>&1 | tee "$softname-$softversion-build.log"
